# Generated by Django 2.2 on 2022-02-12 16:20

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('django', '0003_auto_20220212_1614'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='conditiongroup',
            name='grid',
        ),
        migrations.AddField(
            model_name='grid',
            name='condition_group',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='django.ConditionGroup'),
        ),
    ]
