# Generated by Django 2.2 on 2023-02-10 10:29

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('django', '0007_auto_20220610_0642'),
    ]

    operations = [
        migrations.CreateModel(
            name='Document',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(blank=True, default='', max_length=255, null=True)),
                ('comment', models.CharField(blank=True, default='', max_length=255, null=True)),
            ],
        ),
        migrations.CreateModel(
            name='Template',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(blank=True, default='', max_length=255, null=True)),
                ('comment', models.CharField(blank=True, default='', max_length=255, null=True)),
            ],
        ),
        migrations.CreateModel(
            name='TemplateItem',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('label', models.CharField(blank=True, default='', max_length=255, null=True)),
                ('type', models.IntegerField(default=0)),
                ('order', models.IntegerField(default=0)),
                ('comment', models.CharField(blank=True, default='', max_length=255, null=True)),
                ('optional', models.BooleanField(default=False)),
                ('template', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='django.Template')),
            ],
        ),
        migrations.CreateModel(
            name='DocumentItem',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('label', models.CharField(blank=True, default='', max_length=255, null=True)),
                ('value', models.CharField(blank=True, default='', max_length=255, null=True)),
                ('document', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='django.Document')),
            ],
        ),
        migrations.AddField(
            model_name='document',
            name='template',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='django.Template'),
        ),
    ]
