# Generated by Django 2.2 on 2022-06-10 06:42

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('django', '0006_auto_20220610_0534'),
    ]

    operations = [
        migrations.RenameField(
            model_name='column',
            old_name='sort',
            new_name='order_by',
        ),
    ]
